@@ -11,11 +11,14 @@ class Serbia(OrthodoxCalendar):
         (1, 7, "Christmas"),
         (2, 15, "Statehood Day"),
         (2, 16, "Statehood Day"),
-        (5, 1, "Labour Day"),
         (5, 2, "Labour Day Holiday"),
         (11, 11, "Armistice Day"),
     )
 
+    # Civil holidays
+    include_labour_day = True
+
+    # Christian holidays
     include_good_friday = True
     include_easter_sunday = True
     include_easter_monday = True
