@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
 from unittest import TestCase
 
-from workalendar.asia import (
+from ..asia import (
+    China,
     HongKong,
     Japan,
     Malaysia,
@@ -11,13 +11,14 @@ from workalendar.asia import (
     Taiwan,
 )
 
-from workalendar.registry import registry
+from ..registry import registry
 
 
 class RegistryAsia(TestCase):
     def test_asia(self):
         classes = (v for k, v in registry.region_registry.items())
         classes = list(classes)
+        self.assertIn(China, classes)
         self.assertIn(HongKong, classes)
         self.assertIn(Japan, classes)
         self.assertIn(Malaysia, classes)
